==> mywwwatcher-3.1.tbz: www/mywwwatcher/import.php <==
<?php
session_name ("mywauthid");
session_start();

include ("function.php");
include ("lang/" . $_SESSION['lang']) . ".lng";

authorization_check ();
$db = db_connect();

include ("include/headers.inc.php");
?>


<body leftmargin="13" topmargin="13" bottommargin="30" rightmargin="5" bgcolor="<?php echo $_SESSION['color_right'];?>">

<?php

echo "<b>" . IMPORT_DB . " " . $_SESSION['xdb'] . "</b><br/><br/>\n";


if (!empty($_SESSION[xdb]))	{

	if ($_POST['odes']) 	{

		$_SESSION['first_error'] = $_POST['first_error'];

		if ($_FILES[dump_file]['name'] )	{
			if (eregi(".zip$", $_FILES[dump_file]['name']))		{

				if (function_exists('zip_open'))	{
					$zip = zip_open($_FILES[dump_file]['tmp_name']);
					if ($zip) {

						while ($zip_entry = zip_read($zip)) {
							if (zip_entry_open($zip, $zip_entry, "r")) {
								$imp_t = zip_entry_read($zip_entry, zip_entry_filesize($zip_entry));
								zip_entry_close($zip_entry);
// je tohle spravne?
// musi to byt v poli, nevim, jestli staci \n nebo musi byt \\n
								$imp_t = explode ("\n", $imp_t);
							}
						}

						zip_close($zip);
					}
					else	{
						echo "<br/>" . ARCHIVE_ERROR;
					}
    			}
				else	{
					echo "<br/>" . ZIP_NOT_FOUND;
				}
			}
			elseif (eregi(".gz$", $_FILES[dump_file]['name']))		{
/*
				if (function_exists('gzopen'))	{
					$zd = gzopen ($_FILES[dump_file]['tmp_name'], "r");
					$imp_t =  gzread ($zd, 10000);
					gzclose ($zd);
*/

				if (function_exists('gzfile'))	{

					$imp_t = gzfile ($_FILES[dump_file]['tmp_name']);


					if (!$imp_t)	{
						echo "<br/>" . ARCHIVE_ERROR;
					}
				}
				else	{
					echo "<br/>" . GZ_NOT_FOUND;
				}

			}
			else	{
				$imp_t = file ($_FILES[dump_file]['tmp_name']);
			}

		}
		elseif ($_POST[dump_text]) 	{
			$imp_t = explode (chr (10), $_POST[dump_text]);
		}

		if ($imp_t)	{

			reset ($imp_t);
			$imp_nt = 0;
		 	$imp_e = 0;
		 	$imp_q = "";
			$error = 0;
			$insert = 0;
			$create = 0;
			$drop = 0;

	 		while ($imp_l = stripslashes(current($imp_t)))	{
		  		$imp_u = trim($imp_l);
		  		if (($imp_u && $imp_u[0] != "#") || $imp_nt) {
		   			$imp_nt = (count (split ("\'",$imp_u)) - count (split ("\\\'",$imp_u)) + $imp_nt)%2;
		   			$imp_q .= $imp_l;
		   			if ($imp_u[strlen($imp_u) - 1] == ";" && !$imp_nt)	{

		    			$imp_q = substr ($imp_q,0,strrpos ($imp_q,";"));

						$imp_v = mysql_db_query($_SESSION['xdb'],$imp_q,$db);
		    			if (!$imp_v)	{

		     				echo $imp_q . "<br/>\n";
		     				echo "<br/><b>" . ERROR_QUERY . ":</b> " . mysql_errno() . ": " . mysql_error() . "\n";
		     				echo "<br/><br/>\n";
   							$error++;
	 						if ($_SESSION['first_error'] == 1 )	{
								end($imp_t);
							}
		    			}
						else	{
           					$imp_q = strtolower($imp_q);
							if (strstr ($imp_q,"insert "))	{
                               	$insert++;
							}
							if (strstr ($imp_q,"create "))	{
								$create++;
							}
							if (strstr ($imp_q,"drop "))	{
								$drop++;
							}

						}
		    			$imp_q = "";
		   			}
		 		}
		  		next ($imp_t);
			}

			if ($error > 0)	{
				if ($_SESSION['first_error'] == 1)	{
					echo "<br/><br/>" . IMPORT_STOP . "<br/><br/>";
				}
				else	{
					echo "<br/><br/>" . IMPORT_ERROR . "$error<br/><br/>";
				}
			}
			else	{
				echo "<br/><br/>" . IMPORT_OK . "<br/><br/>";
			}

			echo DROPED . ": $drop<br/>";
			echo CREATED . ": $create<br/>";
			echo INSERTED . ":  $insert<br/>";

			if ($create > 0 || $drop > 0 || ($_SESSION[count_view] && $insert > 0))		{
				echo "<script language=\"javascript\">top.frm_left.document.location.href='menu.php?" . SID . "';</script>\n";
			}
		}
		echo "<br/><br/>";
	}


	?>

	<form action="<?php echo $_SERVER['PHP_SELF'] . "?" . SID ;?>" method="post" name="dataform" enctype="multipart/form-data">
	<table cellpadding="0" cellspacing="0" border="0" width="100%" class="border_no">
	<tr><td>
		<span class="nadpis"><?php echo DUMPTEXT; ?></span><br/>
		<textarea name="dump_text" style="width: 100%;" rows="16" nowrap="nowrap"></textarea>
		<br/><br/>

<?php
	if (ini_get ("file_uploads"))	{
?>
		<span class="nadpis"><?php echo DUMPFILE; ?></span><br/>
		<input type="file" name="dump_file" />
		<br/><br/>
<?php
	}
	else	{
		echo UPLOAD_INFO . "\n<br/><br/>";
	}


		echo EXTRACT_INFO . "\n";

		echo "<br/><br/><br/>";
		echo "<input type=\"checkbox\" class=\"noborder\" name=\"first_error\" ";
		echo $_SESSION['first_error'] ? " checked=\"checked\" " : " ";
		echo " /> " . IMPORT_STOP . "\n";
?>

	<br/><br/>

		<input type="button" name="odes" value="<?php echo GO; ?>" class="butonek" onclick="submit(this);" />

		<INPUT type="hidden" name="odes" value="1" />
		</form>
	</td></tr></table>
	<br/><br/>

<?php
}
else	{	// nebyla zvolena databaze

	echo NO_SEL_DB;

}

include ("include/foot.inc.php");

?>

==> mywwwatcher-3.2.tbz: www/mywwwatcher/import.php <==
<?php
session_name ("mywauthid");
session_start();

include ("function.php");
include ("lang/" . $_SESSION['lang']) . ".lng";

authorization_check ();
$db = db_connect();

include ("include/headers.inc.php");
?>

<body id="frm_right" bgcolor="<?php echo $_SESSION['color_right'];?>">

<?php

echo "<strong>" . IMPORT_DB . " " . $_SESSION['xdb'] . "</strong><br /><br />\n";


if (!empty($_SESSION[xdb]))	{

	if ($_POST) 	{

		$_SESSION['first_error'] = $_POST['first_error'];

        if ($_FILES[dump_file]['size'] < ini_get ("upload_max_filesize"))   {
            echo FILE_SIZE_BIG;
        }
		elseif ($_FILES[dump_file]['name'])	{

			if (eregi(".zip$", $_FILES[dump_file]['name']))		{

				if (function_exists('zip_open'))	{
					$zip = zip_open($_FILES[dump_file]['tmp_name']);
					if ($zip) {

						while ($zip_entry = zip_read($zip)) {
							if (zip_entry_open($zip, $zip_entry, "r")) {
								$imp_t = zip_entry_read($zip_entry, zip_entry_filesize($zip_entry));
								zip_entry_close($zip_entry);
								$imp_t = explode ("\n", $imp_t);
							}
						}

						zip_close($zip);
					}
					else	{
						echo "<br/>" . ARCHIVE_ERROR;
					}
    			}
				else	{
					echo "<br/>" . ZIP_NOT_FOUND;
				}
			}
			elseif (eregi(".gz$", $_FILES[dump_file]['name']))		{
				if (function_exists('gzfile'))	{
					$imp_t = gzfile ($_FILES[dump_file]['tmp_name']);
					if (!$imp_t)	{
						echo "<br/>" . ARCHIVE_ERROR;
					}
				}
				else	{
					echo "<br/>" . GZ_NOT_FOUND;
				}
			}
			else	{
				$imp_t = file ($_FILES[dump_file]['tmp_name']);
			}
		}
		elseif ($_POST[dump_text]) 	{
			$imp_t = explode (chr (10), $_POST[dump_text]);
		}

		if ($imp_t)	{

			reset ($imp_t);
			$imp_nt = 0;
		 	$imp_e = 0;
		 	$imp_q = "";
			$error = 0;
			$insert = 0;
			$create = 0;
			$drop = 0;

	 		while ($imp_l = stripslashes(current($imp_t)))	{
		  		$imp_u = trim($imp_l);
		  		if (($imp_u && $imp_u[0] != "#") || $imp_nt) {
		   			$imp_nt = (count (split ("\'",$imp_u)) - count (split ("\\\'",$imp_u)) + $imp_nt)%2;
		   			$imp_q .= $imp_l;


		   			if (($imp_u[strlen($imp_u) - 1] == ";" || count($imp_t)-1==key($imp_t)) && !$imp_nt)	{
                        $sep_pos = strrpos ($imp_q,";");
                        if($sep_pos===false){
                            $sep_pos = strlen($imp_q);
                        }
	    			    $imp_q = substr ($imp_q,0,$sep_pos);
					    $imp_v = mysql_db_query($_SESSION['xdb'],$imp_q,$db);
	    			    if (!$imp_v)	{
	     				  echo $imp_q . "<br/>\n";
	     				  echo "<br/><b>" . ERROR_QUERY . ":</b> " . mysql_errno() . ": " . mysql_error() . "\n";
	     				  echo "<br/><br/>\n";
						  $error++;
 						  if ($_SESSION['first_error'] == 1 )	{
						      end($imp_t);
						  }
	    			    }
						else	{
           					$imp_q = strtolower($imp_q);
							if (strstr ($imp_q,"insert "))	{
                               	$insert++;
							}
							if (strstr ($imp_q,"create "))	{
								$create++;
							}
							if (strstr ($imp_q,"drop "))	{
								$drop++;
							}
						}
		    			$imp_q = "";
		   		     }
		 		}
		  		next ($imp_t);
			}

			if ($error > 0)	{
				if ($_SESSION['first_error'] == 1)	{
					echo "<br/><br/>" . IMPORT_STOP . "<br/><br/>";
				}
				else	{
					echo "<br/><br/>" . IMPORT_ERROR . "$error<br/><br/>";
				}
			}
			else	{
				echo "<br/><br/>" . IMPORT_OK . "<br/><br/>";
			}

			echo DROPED . ": $drop<br/>";
			echo CREATED . ": $create<br/>";
			echo INSERTED . ":  $insert<br/>";

			if ($create > 0 || $drop > 0 || ($_SESSION[count_view] && $insert > 0))		{
				echo "<script language=\"javascript\">top.frm_left.document.location.href='menu.php?" . SID . "';</script>\n";
			}
		}
		echo "<br/><br/>";
	}
?>

	<form action="<?php echo $_SERVER['PHP_SELF'] . "?" . SID ;?>" method="post" name="dataform" enctype="multipart/form-data">
	<table class="border_no">
	<tr><td>
		<strong><?php echo DUMPTEXT; ?></strong><br />
		<textarea name="dump_text" class="dump"></textarea>
		<br /><br />

<?php
	if (ini_get ("file_uploads"))	{
?>
		<strong><?php echo DUMPFILE . "&nbsp; (Max. " . ini_get ("upload_max_filesize"); ?>)</strong><br />
		<input type="file" name="dump_file" />
<?php
		echo "<br/>" . EXTRACT_INFO . "\n";
?>

		<br /><br />
<?php
	}
	else	{
		echo UPLOAD_INFO . "\n<br /><br />";
	}



		echo "<br /><br /><br />";
		echo "<input type=\"checkbox\" class=\"noborder\" name=\"first_error\" ";
		echo $_SESSION['first_error'] ? " checked=\"checked\" " : " ";
		echo " /> " . IMPORT_STOP . "\n";
?>

	<br /><br />

		<input type="button" name="odes" value="<?php echo GO; ?>" class="butonek" onclick="submit(this);" />

		<INPUT type="hidden" name="odes" value="1" />
	</td></tr></table>
		</form>


<?php
}
else	{	// nebyla zvolena databaze

	echo NO_SEL_DB;

}

include ("include/foot.inc.php");

?>
